--
-- LightActivateAI
-- This is the specialization for LightActivateAI
--
-- @ Autor  Tobias F. (John Deere 6930)
-- @ Last Edit 25/07/2010
-- Edited by MoonDragon 04/2022 (with beleuchtungV31, add normalLightsKey="true" in <lights )

LightActivateAI = {};

function LightActivateAI.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function LightActivateAI:load(xmlFile)
	self.setLightState = LightActivateAI.setLightState;
	self.isLightActivateAI = true;
	
	local numlights = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.lights#count"), 0);
	self.normalLightsKey = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.lights#normalLightsKey"), true);
    self.lights = {};
    for i=1, numlights do
        local lightnamei = string.format("vehicle.lights.light" .. "%d", i);
        self.lights[i] = {};
        self.lights[i].node = Utils.indexToObject(self.components, getXMLString(xmlFile, lightnamei .. "#index"));
        self.lights[i].aiNode = Utils.indexToObject(self.components, getXMLString(xmlFile, lightnamei .. "#AIindex"));
        setVisibility(self.lights[i].node, false); 
		setVisibility(self.lights[i].aiNode, false);
    end;
	self.normalLightsActive = false;
	
	local numWorklights = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.Worklights#count"), 0);
	self.workLightsKey = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.Worklights#workLightsKey"), true);
    self.Worklights = {};
    for i=1, numWorklights do
        local lightnamei = string.format("vehicle.Worklights.light" .. "%d", i);
        self.Worklights[i] = {};
		self.Worklights[i].node = Utils.indexToObject(self.components, getXMLString(xmlFile, lightnamei .. "#index"));		
        self.Worklights[i].aiNode = Utils.indexToObject(self.components, getXMLString(xmlFile, lightnamei .. "#AIindex"));
        setVisibility(self.Worklights[i].node, false); 
		setVisibility(self.Worklights[i].aiNode, false);
    end;
	self.workLightsActive = false;
	
	self.deactivateNormalOnWork = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.lights#deactivateNormalOnWork"), false);
	self.deactivateWorkOnNormal = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.Worklights#deactivateWorkOnNormal"), false);
end;

function LightActivateAI:delete()
end;

function LightActivateAI:setLightState(LightType, state)
	local lights = nil;
	if LightType == "Normal" then
		lights = self.lights;
	elseif LightType == "Work" then
		lights = self.Worklights;
	end;
	if lights == nil then
		print("Error: No accepted LightType!")
	else
		for k,light in pairs(lights) do		
			if state then
				setVisibility(light.aiNode, true);
				if not self.isHired then
					setVisibility(light.node, true);
				else
					setVisibility(light.node, false);
				end;					
			else
				setVisibility(light.node, false); 
				setVisibility(light.aiNode, false);				
			end;
		end;
	end;
end;

function LightActivateAI:mouseEvent(posX, posY, isDown, isUp, button)
end;

function LightActivateAI:keyEvent(unicode, sym, modifier, isDown)
end;

function LightActivateAI:update(dt)
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.TOGGLE_LIGHTS) and self.normalLightsKey then
			self.normalLightsActive = not self.normalLightsActive;
			self:setLightState("Normal", self.normalLightsActive);
		end;
		if InputBinding.hasEvent(InputBinding.TOGGLE_WORKLIGHTS) and self.workLightsKey then
			self.workLightsActive = not self.workLightsActive;
			self:setLightState("Work", self.workLightsActive);
		end;
	end;
	if self:getIsActive() then
		if self.workLightsActive then
			self:setLightState("Work", true);
			if self.deactivateNormalOnWork then
				self:setLightState("Normal", false);
			end;
		end;
		if self.normalLightsActive then
			self:setLightState("Normal", true);
			if self.deactivateWorkOnNormal then
				self:setLightState("Work", false);
			end;
		end;
	end;
end;

function LightActivateAI:draw()
end;

function LightActivateAI:onLeave()
	if self.deactivateOnLeave then
		self:onDeactivateLights()
	end;
end;

function LightActivateAI:onDeactivateLights()
	self:setLightState("Normal", false);
	self:setLightState("Work", false);
end;